# generated by datamodel-codegen:
#   filename:  enums/media_buy_status.json
#   timestamp: 2026-02-12T02:11:19+00:00

from __future__ import annotations

from enum import Enum


class MediaBuyStatus(Enum):
    pending_activation = 'pending_activation'
    active = 'active'
    paused = 'paused'
    completed = 'completed'
